"""
    Module FACT_unified_data_IO

A Julia module for interfacing with a MySQL database, specifically designed for managing and interacting with FACT consolidated data.

This module provides functionalities to establish connections to a MySQL database, retrieve and write data to tables, and manage a manifest table for tracking database table associations with specific method calls and arguments.

## Features

- **Database Connection Management**: Functions to establish and close connections to a MySQL database.
- **Data Retrieval and Writing**: Functions to read from and write to database tables.
- **Manifest Management**: Functions to interact with a manifest table that maps method calls and arguments to specific database tables.

## Usage

The module exports various functions from included scripts. Key functionalities include getting connections to a MySQL database, closing connections, managing data tables, and interacting with a manifest table.

### Exported Functions

- `get_connection`: Establish a connection to a MySQL database.
- `close_connection`: Close an established connection to a MySQL database.
- `get_table`: Retrieve data from a specific table based on method name and arguments.
- `write_table`: Write data to a table and record its details in the manifest.
- `overwrite_table`: Overwrite data in a table and update the manifest.

## Dependencies

- `MySQL.jl`: For MySQL database connectivity and operations.
- `JSON.jl`: For JSON parsing and serialization.
- `DataFrames.jl`: For handling data in tabular form.

"""
module FACT_unified_data_IO

    using MySQL, JSON, DataFrames, UUIDs, Dates, SHA
    using OrchestratorRegistry
    
    include("utils/db.jl")
    export get_results_connection, close_connection

    include("utils/manifestIO.jl")
    export get_table, write_table, overwrite_table, does_table_exist_for_method

end
